@@ -20,7 +20,7 @@ def lint():
     Checks the source code using flake8.
     """
     local('flake8 --statistics --exit-zero --max-complexity=10 '
-          '--exclude=\'*/migrations/*,build,dist\' .')
+          '--exclude=\'*/migrations/*,build,dist,docs\' .')
 
 
 @task
@@ -74,7 +74,7 @@ def release():
                                        pipes.quote(tag_message)))
 
     # Push
-    local('git push origin master')
+    local('git push --tags origin master')
 
     # Package and upload to pypi
-    local('python setup.py sdist upload')
+    local('python setup.py sdist bdist_wheel upload')
